==> kubernetes-model-autoscaling-6.1.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ContainerResourceMetricSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ContainerResourceMetricSourceFluentImpl<A extends ContainerResourceMetricSourceFluent<A>> extends BaseFluent<A> implements ContainerResourceMetricSourceFluent<A>{
  public ContainerResourceMetricSourceFluentImpl() {
  }
  public ContainerResourceMetricSourceFluentImpl(ContainerResourceMetricSource instance) {
    this.withContainer(instance.getContainer()); 
    this.withName(instance.getName()); 
    this.withTarget(instance.getTarget()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String container;
  private String name;
  private MetricTargetBuilder target;
  private Map<String,Object> additionalProperties;
  public String getContainer() {
    return this.container;
  }
  public A withContainer(String container) {
    this.container=container; return (A) this;
  }
  public Boolean hasContainer() {
    return this.container != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * This method has been deprecated, please use method buildTarget instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricTarget getTarget() {
    return this.target!=null ?this.target.build():null;
  }
  public MetricTarget buildTarget() {
    return this.target!=null ?this.target.build():null;
  }
  public A withTarget(MetricTarget target) {
    _visitables.get("target").remove(this.target);
    if (target!=null){ this.target= new MetricTargetBuilder(target); _visitables.get("target").add(this.target);} else { this.target = null; _visitables.get("target").remove(this.target); } return (A) this;
  }
  public Boolean hasTarget() {
    return this.target != null;
  }
  public ContainerResourceMetricSourceFluent.TargetNested<A> withNewTarget() {
    return new ContainerResourceMetricSourceFluentImpl.TargetNestedImpl();
  }
  public ContainerResourceMetricSourceFluent.TargetNested<A> withNewTargetLike(MetricTarget item) {
    return new ContainerResourceMetricSourceFluentImpl.TargetNestedImpl(item);
  }
  public ContainerResourceMetricSourceFluent.TargetNested<A> editTarget() {
    return withNewTargetLike(getTarget());
  }
  public ContainerResourceMetricSourceFluent.TargetNested<A> editOrNewTarget() {
    return withNewTargetLike(getTarget() != null ? getTarget(): new MetricTargetBuilder().build());
  }
  public ContainerResourceMetricSourceFluent.TargetNested<A> editOrNewTargetLike(MetricTarget item) {
    return withNewTargetLike(getTarget() != null ? getTarget(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ContainerResourceMetricSourceFluentImpl that = (ContainerResourceMetricSourceFluentImpl) o;
    if (container != null ? !container.equals(that.container) :that.container != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (target != null ? !target.equals(that.target) :that.target != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(container,  name,  target,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (container != null) { sb.append("container:"); sb.append(container + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (target != null) { sb.append("target:"); sb.append(target + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class TargetNestedImpl<N> extends MetricTargetFluentImpl<ContainerResourceMetricSourceFluent.TargetNested<N>> implements ContainerResourceMetricSourceFluent.TargetNested<N>,Nested<N>{
    TargetNestedImpl(MetricTarget item) {
      this.builder = new MetricTargetBuilder(this, item);
    }
    TargetNestedImpl() {
      this.builder = new MetricTargetBuilder(this);
    }
    MetricTargetBuilder builder;
    public N and() {
      return (N) ContainerResourceMetricSourceFluentImpl.this.withTarget(builder.build());
    }
    public N endTarget() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-autoscaling-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ContainerResourceMetricSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ContainerResourceMetricSourceFluentImpl<A extends ContainerResourceMetricSourceFluent<A>> extends BaseFluent<A> implements ContainerResourceMetricSourceFluent<A>{
  public ContainerResourceMetricSourceFluentImpl() {
  }
  public ContainerResourceMetricSourceFluentImpl(ContainerResourceMetricSource instance) {
    if (instance != null) {
      this.withContainer(instance.getContainer());
      this.withName(instance.getName());
      this.withTarget(instance.getTarget());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String container;
  private String name;
  private MetricTargetBuilder target;
  private Map<String,Object> additionalProperties;
  public String getContainer() {
    return this.container;
  }
  public A withContainer(String container) {
    this.container=container; return (A) this;
  }
  public Boolean hasContainer() {
    return this.container != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * This method has been deprecated, please use method buildTarget instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricTarget getTarget() {
    return this.target!=null ?this.target.build():null;
  }
  public MetricTarget buildTarget() {
    return this.target!=null ?this.target.build():null;
  }
  public A withTarget(MetricTarget target) {
    _visitables.get("target").remove(this.target);
    if (target!=null){ this.target= new MetricTargetBuilder(target); _visitables.get("target").add(this.target);} else { this.target = null; _visitables.get("target").remove(this.target); } return (A) this;
  }
  public Boolean hasTarget() {
    return this.target != null;
  }
  public ContainerResourceMetricSourceFluentImpl.TargetNested<A> withNewTarget() {
    return new ContainerResourceMetricSourceFluentImpl.TargetNestedImpl();
  }
  public ContainerResourceMetricSourceFluentImpl.TargetNested<A> withNewTargetLike(MetricTarget item) {
    return new ContainerResourceMetricSourceFluentImpl.TargetNestedImpl(item);
  }
  public ContainerResourceMetricSourceFluentImpl.TargetNested<A> editTarget() {
    return withNewTargetLike(getTarget());
  }
  public ContainerResourceMetricSourceFluentImpl.TargetNested<A> editOrNewTarget() {
    return withNewTargetLike(getTarget() != null ? getTarget(): new MetricTargetBuilder().build());
  }
  public ContainerResourceMetricSourceFluentImpl.TargetNested<A> editOrNewTargetLike(MetricTarget item) {
    return withNewTargetLike(getTarget() != null ? getTarget(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ContainerResourceMetricSourceFluentImpl that = (ContainerResourceMetricSourceFluentImpl) o;
    if (!java.util.Objects.equals(container, that.container)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(target, that.target)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(container,  name,  target,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (container != null) { sb.append("container:"); sb.append(container + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (target != null) { sb.append("target:"); sb.append(target + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class TargetNestedImpl<N> extends MetricTargetFluentImpl<ContainerResourceMetricSourceFluentImpl.TargetNested<N>> implements ContainerResourceMetricSourceFluentImpl.TargetNested<N>,Nested<N>{
    TargetNestedImpl(MetricTarget item) {
      this.builder = new MetricTargetBuilder(this, item);
    }
    TargetNestedImpl() {
      this.builder = new MetricTargetBuilder(this);
    }
    MetricTargetBuilder builder;
    public N and() {
      return (N) ContainerResourceMetricSourceFluentImpl.this.withTarget(builder.build());
    }
    public N endTarget() {
      return and();
    }
    
  }
  
}
